@@ -1,27 +1,43 @@
-/*                                                                              
- * PDFedit - free program for PDF document manipulation.                        
- * Copyright (C) 2006, 2007  PDFedit team:      Michal Hocko, 
- *                                              Miroslav Jahoda,       
- *                                              Jozef Misutka, 
- *                                              Martin Petricek                                             
+/*
+ * PDFedit - free program for PDF document manipulation.
+ * Copyright (C) 2006-2009  PDFedit team: Michal Hocko,
+ *                                        Jozef Misutka,
+ *                                        Martin Petricek
+ *                   Former team members: Miroslav Jahoda
  *
- * Project is hosted on http://sourceforge.net/projects/pdfedit                                                                      
- */ 
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; version 2 of the License.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program (in doc/LICENSE.GPL); if not, write to the 
+ * Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, 
+ * MA  02111-1307  USA
+ *
+ * Project is hosted on http://sourceforge.net/projects/pdfedit
+ */
 /** @file
  "Merge documents pages" dialog<br>
  This dialog is used to select another PDF document and
  merge pages from that document in currently edited document
 */
 
+#include "mergeform.h"
+#include "pdfutil.h"
+#include "util.h"
 #include <qvariant.h>
 #include <qpushbutton.h>
 #include <qlabel.h>
 #include <qlineedit.h>
 #include <qframe.h>
-#include <qlistbox.h>
+#include QLISTBOX
 #include <qlayout.h>
-#include <cpdf.h>
-#include "mergeform.h"
+#include <kernel/cpdf.h>
 
 namespace gui {
 
@@ -62,16 +78,16 @@ struct NodeData {
 /** List box item.
  * Inherits from QListBoxText item type and adds NodeData data field.
  */
-class ListItem:public QListBoxText {
+class ListItem:public Q_ListBoxText {
         NodeData * nodeData;
 public:
-        ListItem(NodeData * _nodeData, QListBox * _parent, const QString & text = QString::null):QListBoxText(_parent, text), nodeData(_nodeData)
+        ListItem(NodeData * _nodeData, Q_ListBox * _parent, const QString & text = QString::null):Q_ListBoxText(_parent, text), nodeData(_nodeData)
         {
         }
-        ListItem(NodeData * _nodeData, const QString & text = QString::null):QListBoxText(text), nodeData(_nodeData)
+        ListItem(NodeData * _nodeData, const QString & text = QString::null):Q_ListBoxText(text), nodeData(_nodeData)
         {
         }
-        ListItem(NodeData * _nodeData, QListBox * _parent, const QString & text, QListBoxItem * after):QListBoxText(_parent, text, after), nodeData(_nodeData)
+        ListItem(NodeData * _nodeData, Q_ListBox * _parent, const QString & text, Q_ListBoxItem * after):Q_ListBoxText(_parent, text, after), nodeData(_nodeData)
         {
         }
 
@@ -101,14 +117,14 @@ public:
         }
 };
 
-void MergeDialog::mergeList_currentChanged( QListBoxItem * item)
+void MergeDialog::mergeList_currentChanged( Q_ListBoxItem * item)
 {
         ListItem * listItem=dynamic_cast<ListItem *>(item);
         if(listItem==NULL)
                 return;
 
         // enables to manipulate only with FROMFILE nodes
-        // original items has to be in same order as in 
+        // original items has to be in same order as in
         // creation time
         if(listItem->isType(NodeData::FROMFILE)) {
                 removeBtn->setEnabled(TRUE);
@@ -117,13 +133,15 @@ void MergeDialog::mergeList_currentChanged( QListBoxItem * item)
                 // item
                 if(mergeList->currentItem()>0)
                         upBtn->setEnabled(TRUE);
-                else 
+                else
                         upBtn->setEnabled(FALSE);
-                
-                // down button is enabled only if we are not on last
-                // item
-                if(mergeList->currentItem() + 1>=(int)(mergeList->count())) downBtn->setEnabled(FALSE);
-                else downBtn->setEnabled(TRUE);
+
+                // down button is enabled only if we are before END page
+                // pageCount includes also already added pages
+                if(mergeList->currentItem()+1 >= pageCount) 
+			downBtn->setEnabled(FALSE);
+                else 
+			downBtn->setEnabled(TRUE);
         } else {
                 upBtn->setEnabled(FALSE);
                 downBtn->setEnabled(FALSE);
@@ -132,7 +150,7 @@ void MergeDialog::mergeList_currentChanged( QListBoxItem * item)
 }
 
 
-void MergeDialog::fileList_currentChanged( QListBoxItem * ) {
+void MergeDialog::fileList_currentChanged( Q_ListBoxItem * ) {
  // allways enable add button when something is selected
  if(!addBtn->isEnabled()) addBtn->setEnabled(TRUE);
 }
@@ -148,7 +166,7 @@ void MergeDialog::addBtn_clicked()
                 // skips unselected items
                 if(!fileList->isSelected(i))
                         continue;
-                
+
                 ListItem * fileItem=dynamic_cast<ListItem *>(fileList->item(i));
                 if(!fileItem)
                         continue;
@@ -164,6 +182,9 @@ void MergeDialog::addBtn_clicked()
                 // gets position of selected item in mergeList
                 int pos=mergeList->currentItem();
 
+                // increase total page count
+                pageCount++;
+
                 // insert fileItem before currently selected node in mergeList
                 mergeList->insertItem(fileItem, (pos<0)?0:pos);
                 mergeList->setSelected(fileItem, FALSE);
@@ -182,7 +203,7 @@ void MergeDialog::addBtn_clicked()
                 addBtn->setEnabled(FALSE);
                 return;
         }
-        
+
         // select and mark as current element behind last added
         // to mergeList
         if(oldPos>=0)
@@ -211,7 +232,7 @@ void MergeDialog::removeBtn_clicked()
 
                 // insert to correct position in fileList - keeps ordering
                 int pos=0;
-                while(QListBoxItem * item=fileList->item(pos))
+                while(Q_ListBoxItem * item=fileList->item(pos))
                 {
                         ListItem * i=dynamic_cast<ListItem *>(item);
                         if(!i)
@@ -224,9 +245,17 @@ void MergeDialog::removeBtn_clicked()
                         ++pos;
                 }
 
-                // inserts mergeItem to correct position and unselect it
+                // update total page count
+                pageCount--;
+
+                // inserts mergeItem to the correct position and select the next
+                // one in the mergeList
                 fileList->insertItem(mergeItem, pos);
-                fileList->setCurrentItem(mergeItem);
+                // QT3 bug work-around - currentChanged is not triggered when we add
+                // the first item to an empt list - we have to force the handler for
+                // proper enable/disable logic
+                fileList->setCurrentItem(pos);
+                fileList_currentChanged(mergeItem);
                 mergeList->setCurrentItem(oldPos);
                 mergeList->setSelected(oldPos, TRUE);
         }else
@@ -238,7 +267,7 @@ void MergeDialog::upBtn_clicked() {
         int pos=mergeList->currentItem();
         if (pos>0) {
                 // current item can be moved upwards
-                QListBoxItem * item=mergeList->item(pos);
+                Q_ListBoxItem * item=mergeList->item(pos);
 
                 // removes and insert with decremented position
                 mergeList->takeItem(item);
@@ -250,8 +279,8 @@ void MergeDialog::upBtn_clicked() {
 
 void MergeDialog::downBtn_clicked() {
         int pos=mergeList->currentItem();
-        if (pos<(int)(mergeList->count())) {
-                QListBoxItem * item=mergeList->item(pos);
+        if (pos+1<pageCount) {
+                Q_ListBoxItem * item=mergeList->item(pos);
                 mergeList->takeItem(item);
                 mergeList->insertItem(item, pos+1);
                 mergeList->setCurrentItem(item);
@@ -269,7 +298,7 @@ void MergeDialog::openBtn_clicked() {
         initFileList(fileName);
         // TODO handle when file doesn't exist or error occured
         // during CPdf creation
-        
+
         // Open dialog causes disabling fileNameInput and fileNameBtn
         // and enabling merging stuff
         openBtn->setEnabled(FALSE);
@@ -307,14 +336,14 @@ MergeArray<int> * MergeDialog::getResult()
                         continue;
                 }
                 pages[length]=item->getNodeData()->position;
-                positions[length]=storePos; 
+                positions[length]=storePos;
                 ++length;
         }
 
         MergeArray<int> * mergeArray=new MergeArray<int>(length);
         mergeArray->initItems(pages);
         mergeArray->initPositions(positions);
-        
+
         return mergeArray;
 }
 
@@ -324,11 +353,14 @@ QString MergeDialog::fileName() {
 
 void MergeDialog::initOriginal( size_t count ) {
  char itemLabel[128];
+ pageCount = count;
  for(size_t i=1; i<=count; ++i) {
   snprintf(itemLabel, 127, "Page%d", (int)i);
   //ListItem * listItem=
   new ListItem(new NodeData(NodeData::ORIGINAL, i), mergeList, itemLabel);
  }
+ new ListItem(new NodeData(NodeData::ORIGINAL, count+1), mergeList, 
+		 QString("[")+tr("END","end of document marker")+QString("]"));
 }
 
 
@@ -343,11 +375,11 @@ void MergeDialog::destroyOpenFile()
  @return true in case of success, false in case of failure (missing ,broken or unreadable pdf file)
 */
 bool MergeDialog::initFileList( QString & fileName ) {
- CPdf *document;
+ boost::shared_ptr<CPdf> document;
  CPdf::OpenMode mode=CPdf::ReadOnly;
  try {
   guiPrintDbg(debug::DBG_DBG,"Opening document");
-  document=CPdf::getInstance(fileName,mode);
+  document=util::getPdfInstance(this,util::convertFromUnicode(fileName,util::NAME),mode);
   assert(document);
   guiPrintDbg(debug::DBG_DBG,"Opened document");
  } catch (PdfOpenException &ex) {
@@ -357,7 +389,7 @@ bool MergeDialog::initFileList( QString & fileName ) {
   return false;
  }
  size_t count = document->getPageCount();
- document->close();
+ document.reset();
  char itemLabel[128];
  QFileInfo fi(fileName);
  QString baseName=fi.baseName(false);
@@ -382,11 +414,11 @@ MergeDialog::MergeDialog( QWidget* parent, const char* name, bool modal, WFlags
 {
     if ( !name )
 	setName( "MergeDialog" );
-    MergeDialogLayout = new QGridLayout( this, 1, 1, 11, 6, "MergeDialogLayout"); 
+    MergeDialogLayout = new QGridLayout( this, 1, 1, 11, 6, "MergeDialogLayout");
 
-    layout48 = new QVBoxLayout( 0, 0, 6, "layout48"); 
+    layout48 = new QVBoxLayout( 0, 0, 6, "layout48");
 
-    layout27 = new QHBoxLayout( 0, 0, 6, "layout27"); 
+    layout27 = new QHBoxLayout( 0, 0, 6, "layout27");
 
     textLabel1 = new QLabel( this, "textLabel1" );
     textLabel1->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)0, (QSizePolicy::SizeType)0, 0, 0, textLabel1->sizePolicy().hasHeightForWidth() ) );
@@ -402,7 +434,7 @@ MergeDialog::MergeDialog( QWidget* parent, const char* name, bool modal, WFlags
     layout27->addWidget( fileNameBtn );
     layout48->addLayout( layout27 );
 
-    layout2 = new QHBoxLayout( 0, 0, 6, "layout2"); 
+    layout2 = new QHBoxLayout( 0, 0, 6, "layout2");
     spacer1 = new QSpacerItem( 131, 21, QSizePolicy::Expanding, QSizePolicy::Minimum );
     layout2->addItem( spacer1 );
 
@@ -419,13 +451,13 @@ MergeDialog::MergeDialog( QWidget* parent, const char* name, bool modal, WFlags
     line1->setFrameShape( QFrame::HLine );
     layout48->addWidget( line1 );
 
-    layout47 = new QHBoxLayout( 0, 0, 6, "layout47"); 
+    layout47 = new QHBoxLayout( 0, 0, 6, "layout47");
 
-    mergeList = new QListBox( this, "mergeList" );
+    mergeList = new Q_ListBox( this, "mergeList" );
     mergeList->setEnabled( FALSE );
     layout47->addWidget( mergeList );
 
-    layout4 = new QVBoxLayout( 0, 0, 6, "layout4"); 
+    layout4 = new QVBoxLayout( 0, 0, 6, "layout4");
 
     addBtn = new QPushButton( this, "addBtn" );
     addBtn->setEnabled( FALSE );
@@ -446,14 +478,14 @@ MergeDialog::MergeDialog( QWidget* parent, const char* name, bool modal, WFlags
     layout4->addWidget( downBtn );
     layout47->addLayout( layout4 );
 
-    fileList = new QListBox( this, "fileList" );
+    fileList = new Q_ListBox( this, "fileList" );
     fileList->setEnabled( FALSE );
-    fileList->setFrameShape( QListBox::StyledPanel );
-    fileList->setSelectionMode( QListBox::Extended );
+    fileList->setFrameShape( Q_ListBox::StyledPanel );
+    fileList->setSelectionMode( Q_ListBox::Extended );
     layout47->addWidget( fileList );
     layout48->addLayout( layout47 );
 
-    layout6 = new QHBoxLayout( 0, 0, 5, "layout6"); 
+    layout6 = new QHBoxLayout( 0, 0, 5, "layout6");
 
     spacer5 = new QSpacerItem( 61, 21, QSizePolicy::Expanding, QSizePolicy::Minimum );
     layout6->addItem( spacer5 );
@@ -473,7 +505,7 @@ MergeDialog::MergeDialog( QWidget* parent, const char* name, bool modal, WFlags
     MergeDialogLayout->addLayout( layout48, 0, 0 );
     languageChange();
     resize( QSize(759, 380).expandedTo(minimumSizeHint()) );
-    clearWState( WState_Polished );
+//    clearWState( WState_Polished );
 
     // signals and slots connections
     connect( cancelBtn, SIGNAL( clicked() ), this, SLOT( reject() ) );
@@ -484,8 +516,13 @@ MergeDialog::MergeDialog( QWidget* parent, const char* name, bool modal, WFlags
     connect( downBtn, SIGNAL( clicked() ), this, SLOT( downBtn_clicked() ) );
     connect( openBtn, SIGNAL( clicked() ), this, SLOT( openBtn_clicked() ) );
     connect( fileNameBtn, SIGNAL( clicked() ), this, SLOT( fileNameBtn_clicked() ) );
+#ifdef QT3
     connect( mergeList, SIGNAL( currentChanged(QListBoxItem*) ), this, SLOT( mergeList_currentChanged(QListBoxItem*) ) );
     connect( fileList, SIGNAL( currentChanged(QListBoxItem*) ), this, SLOT( fileList_currentChanged(QListBoxItem*) ) );
+#else
+    connect( mergeList, SIGNAL( currentChanged(Q3ListBoxItem*) ), this, SLOT( mergeList_currentChanged(Q3ListBoxItem*) ) );
+    connect( fileList, SIGNAL( currentChanged(Q3ListBoxItem*) ), this, SLOT( fileList_currentChanged(Q3ListBoxItem*) ) );
+#endif
 
     // tab order
     setTabOrder( fileNameInput, fileNameBtn );
