@@ -1,12 +1,26 @@
-/*                                                                              
- * PDFedit - free program for PDF document manipulation.                        
- * Copyright (C) 2006, 2007  PDFedit team:      Michal Hocko, 
- *                                              Miroslav Jahoda,       
- *                                              Jozef Misutka, 
- *                                              Martin Petricek                                             
+/*
+ * PDFedit - free program for PDF document manipulation.
+ * Copyright (C) 2006-2009  PDFedit team: Michal Hocko,
+ *                                        Jozef Misutka,
+ *                                        Martin Petricek
+ *                   Former team members: Miroslav Jahoda
  *
- * Project is hosted on http://sourceforge.net/projects/pdfedit                                                                      
- */ 
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; version 2 of the License.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program (in doc/LICENSE.GPL); if not, write to the 
+ * Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, 
+ * MA  02111-1307  USA
+ *
+ * Project is hosted on http://sourceforge.net/projects/pdfedit
+ */
 #include "pagespace.h"
 #include QSCROLLVIEW
 #include <stdlib.h>
@@ -23,9 +37,9 @@
 #include QSTRLIST
 
 #include "settings.h"
-#include "cpdf.h"
-#include "cpage.h"
-#include "static.h"
+#include "kernel/cpdf.h"
+#include "kernel/cpage.h"
+#include "kernel/static.h"
 #include "rect2Darray.h"
 
 #include "pageviewmode.h"
@@ -134,7 +148,7 @@ PageSpace::PageSpace(QWidget *parent /*=0*/, const char *name /*=0*/) : QWidget(
 	pageNumber->setAlignment( Qt::AlignCenter | pageNumber->alignment() );
 	hBox->addWidget( pageNumber );
 	hBox->addStretch();
-        
+
  	actualUnits.setDefaultUnits( globalSettings->read( PAGESPC + VIEWED_UNITS, DEFAULT__VIEWED_UNITS ) );
 
 	Init( &is , format + "00000000xx" );
@@ -214,6 +228,12 @@ void PageSpace::refresh ( int pageToView, QSPdf * pdf ) {			// if pdf is NULL re
 			pageToView = 1;
 		
 	pageCount = pdf->get()->getPageCount();
+
+	if (pageCount <= 0) {
+		refresh( (QSPage *) NULL, (QSPdf *) NULL );
+		return;
+	}
+
 	if (pageToView > pageCount)
 			pageToView = pageCount;
 
@@ -310,12 +330,12 @@ int PageSpace::getResizingZone() {
 	// else
 	return globalSettings->readNum( PAGESPC + RESIZINGZONE, DEFAULT__RESIZINGZONE );
 }
-void PageSpace::setSelectionMode( QString mode, 
+void PageSpace::setSelectionMode( QString mode,
 									QString drawingObject,
 									QString scriptFncAtMouseRelease,
 									QString scriptFncAtMoveSelectedObjects,
 									QString scriptFncAtResizeSelectedObjects ) {
-	selectionMode.reset( 
+	selectionMode.reset(
 					PageViewModeFactory::create( mode,
 												drawingObject,
 												scriptFncAtMouseRelease,
@@ -381,7 +401,7 @@ bool PageSpace::saveImageWithDialog ( bool onlySelectedArea ) {
 
 	QFile f ( filename );
 	if ( (! filename.isNull()) &&
-		((! f.exists()) || 
+		((! f.exists()) ||
 			(0 == QMessageBox::question( this, QObject::tr("Overwrite?"),
                                                         QObject::tr("File called \"%1\" already exists. Do you want to overwrite it?").arg( filename ),
 							QObject::tr("&Yes"), QObject::tr("&No"),
@@ -410,11 +430,11 @@ int PageSpace::findText ( QString &text, bool startAtTop, double xStart, double
 	tsp.xEnd = xEnd;
 	tsp.yEnd = yEnd;
 
-	std::vector<Rectangle> recs;
+	std::vector<libs::Rectangle> recs;
 	int count = actualPage->findText( util::convertFromUnicode(text,util::PDF), recs, tsp );
 
 	guiPrintDbg( debug::DBG_DBG, "Founded "<<count<<" items:");
-	for (std::vector<Rectangle>::iterator it = recs.begin(); it != recs.end() ; ++it) {
+	for (std::vector<libs::Rectangle>::iterator it = recs.begin(); it != recs.end() ; ++it) {
 		guiPrintDbg( debug::DBG_DBG, "   ("<<(*it)<<")");
 	}
 
@@ -435,7 +455,7 @@ int PageSpace::findText ( QString &text, bool startAtTop, double xStart, double
 		for ( ; !it.isEnd() ; it.next() ) {
 			boost::shared_ptr<PdfOperator> h_textOp ( it.getCurrent() );
 
-			Rectangle bbox = h_textOp->getBBox();
+			libs::Rectangle bbox = h_textOp->getBBox();
 			if (bbox.xleft > bbox.xright) {
 				double h = bbox.xleft;
 				bbox.xleft = bbox.xright;
@@ -453,7 +473,7 @@ int PageSpace::findText ( QString &text, bool startAtTop, double xStart, double
 			bbox.yright -= bbox.yright / 1e10;
 
 			// loop through bboxes of founded text
-			for ( std::vector<Rectangle>::iterator it_recs = recs.begin(); it_recs != recs.end() ; ++it_recs ) {
+			for ( std::vector<libs::Rectangle>::iterator it_recs = recs.begin(); it_recs != recs.end() ; ++it_recs ) {
 				if ((	( std::min( (*it_recs).xleft, (*it_recs).xright ) <= bbox.xleft ) &&	// if operators width is all inside founded area
 						( std::max( (*it_recs).xleft, (*it_recs).xright ) >= bbox.xright ) &&
 						(std::max( std::min( (*it_recs).yleft, (*it_recs).yright ) , bbox.yleft ) <=	// and has some height intersection
