@@ -1,12 +1,26 @@
-/*                                                                              
- * PDFedit - free program for PDF document manipulation.                        
- * Copyright (C) 2006, 2007  PDFedit team:      Michal Hocko, 
- *                                              Miroslav Jahoda,       
- *                                              Jozef Misutka, 
- *                                              Martin Petricek                                             
+/*
+ * PDFedit - free program for PDF document manipulation.
+ * Copyright (C) 2006-2009  PDFedit team: Michal Hocko,
+ *                                        Jozef Misutka,
+ *                                        Martin Petricek
+ *                   Former team members: Miroslav Jahoda
  *
- * Project is hosted on http://sourceforge.net/projects/pdfedit                                                                      
- */ 
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; version 2 of the License.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program (in doc/LICENSE.GPL); if not, write to the 
+ * Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, 
+ * MA  02111-1307  USA
+ *
+ * Project is hosted on http://sourceforge.net/projects/pdfedit
+ */
 /** @file
  Various utility functions for examining and manipulating pdf objects,
  related to kernel
@@ -15,12 +29,13 @@
 */
 
 #include "pdfutil.h"
+#include "passworddialog.h"
 #include "qtcompat.h"
-#include <qstring.h>
-#include <qobject.h>
-#include <cobject.h>
-#include <cpdf.h>
 #include "util.h"
+#include <kernel/cobject.h>
+#include <kernel/factories.h>
+#include <qobject.h>
+#include <qstring.h>
 #include <utils/debug.h>
 
 namespace util {
@@ -34,16 +49,16 @@ using namespace pdfobjects;
  */
 QString getTypeName(PropertyType typ) {
  switch (typ) {
-  case pNull:   return QObject::tr("Null",	"Type name"); 
-  case pBool:   return QObject::tr("Bool",	"Type name"); 
-  case pInt:    return QObject::tr("Int",	"Type name"); 
-  case pReal:   return QObject::tr("Real",	"Type name"); 
+  case pNull:   return QObject::tr("Null",	"Type name");
+  case pBool:   return QObject::tr("Bool",	"Type name");
+  case pInt:    return QObject::tr("Int",	"Type name");
+  case pReal:   return QObject::tr("Real",	"Type name");
   case pString: return QObject::tr("String",	"Type name");
   case pName:   return QObject::tr("Name",	"Type name");
   case pRef:    return QObject::tr("Ref",	"Type name");
-  case pArray:  return QObject::tr("Array",	"Type name"); 
-  case pDict:   return QObject::tr("Dict",	"Type name"); 
-  case pStream: return QObject::tr("Stream",	"Type name"); 
+  case pArray:  return QObject::tr("Array",	"Type name");
+  case pDict:   return QObject::tr("Dict",	"Type name");
+  case pStream: return QObject::tr("Stream",	"Type name");
 // Debug types
   case pOther:    return QObject::tr("DebugCmd",	"Type name");
   case pOther1:  return QObject::tr("DebugError",	"Type name");
@@ -61,16 +76,16 @@ QString getTypeName(PropertyType typ) {
  */
 QString getTypeId(PropertyType typ) {
  switch (typ) {
-  case pNull:   return "Null"; 
-  case pBool:   return "Bool"; 
+  case pNull:   return "Null";
+  case pBool:   return "Bool";
   case pInt:    return "Int";
   case pReal:   return "Real";
   case pString: return "String";
   case pName:   return "Name";
   case pRef:    return "Ref";
-  case pArray:  return "Array"; 
-  case pDict:   return "Dict"; 
-  case pStream: return "Stream"; 
+  case pArray:  return "Array";
+  case pDict:   return "Dict";
+  case pStream: return "Stream";
 // Debug types
   case pOther:    return "DebugCmd";
   case pOther1:  return "DebugError";
@@ -105,22 +120,22 @@ QString propertyPreview(boost::shared_ptr<IProperty> obj) {
  switch (typ) {
   case pBool: {
    bool value;
-   dynamic_cast<CBool*>(obj.get())->getValue(value);
+   IProperty::getSmartCObjectPtr<CBool>(obj)->getValue(value);
    return value?"true":"false";
   }
   case pInt: {
    int value;
-   dynamic_cast<CInt*>(obj.get())->getValue(value);
+   IProperty::getSmartCObjectPtr<CInt>(obj)->getValue(value);
    return QString::number(value);
   }
   case pReal: {
    double value;
-   dynamic_cast<CReal*>(obj.get())->getValue(value);
+   IProperty::getSmartCObjectPtr<CReal>(obj)->getValue(value);
    return QString::number(value);
   }
   case pName: {
    std::string value;
-   dynamic_cast<CName*>(obj.get())->getValue(value);
+   IProperty::getSmartCObjectPtr<CName>(obj)->getValue(value);
    QString ret=util::convertToUnicode(value,util::PDF);
    if (ret.length()>22) {
     ret.truncate(20);
@@ -130,7 +145,7 @@ QString propertyPreview(boost::shared_ptr<IProperty> obj) {
   }
   case pString: {
    std::string value;
-   dynamic_cast<CString*>(obj.get())->getValue(value);
+   IProperty::getSmartCObjectPtr<CString>(obj)->getValue(value);
    QString ret=util::convertToUnicode(value,util::PDF);
    if (ret.length()>22) {
     ret.truncate(20);
@@ -139,16 +154,19 @@ QString propertyPreview(boost::shared_ptr<IProperty> obj) {
    return ret;
   }
   case pArray: {
-   CArray* a=dynamic_cast<CArray*>(obj.get());
-   return countString(a->getPropertyCount(),"element","elements");
+   size_t count = IProperty::getSmartCObjectPtr<CArray>(obj)->getPropertyCount();
+   return countString(count,"element","elements");
   }
   case pDict: {
-   CDict* a=dynamic_cast<CDict*>(obj.get());
-   return countString(a->getPropertyCount(),"item","items");
+   size_t count = IProperty::getSmartCObjectPtr<CDict>(obj)->getPropertyCount();
+   return countString(count,"item","items");
   }
   case pStream: {
    try {
-    boost::shared_ptr<IProperty> len=dereference(dynamic_cast<CStream*>(obj.get())->getProperty("Length"));
+    boost::shared_ptr<IProperty> len=IProperty::getSmartCObjectPtr<CStream>(obj)->getProperty("Length");
+    // FIXME: Why this check? It can't be NULL AFAIK
+    // dynamic_cast shouldn't be used and IProperty::getSmartCObjectPtr
+    // should be used instead
     CInt* lenInt=dynamic_cast<CInt*>(len.get());
     if (!lenInt) return "";
     int iLen;
@@ -202,7 +220,8 @@ IndiRef getRef(boost::shared_ptr<IProperty> ref) {
  @param ref Indirect reference to check
  @return true if given reference target exists in given pdf, false otherwise
 */
-bool isRefValid(CPdf *pdf,IndiRef ref) {
+bool isRefValid(boost::shared_ptr<CPdf> pdf,IndiRef ref) {
+ assert(pdf);
  CXref *cxref=pdf->getCXref();
  Ref _val;//TODO: why there is no knowsRef(IndiRef) ?
  _val.num=ref.num;
@@ -221,16 +240,16 @@ bool isRefValid(CPdf *pdf,IndiRef ref) {
 bool isSimple(IProperty* prop) {
  PropertyType pt=prop->getType();
  switch(pt) {
-  case pNull: 
-  case pBool: 
-  case pInt: 
-  case pReal: 
-  case pName: 
+  case pNull:
+  case pBool:
+  case pInt:
+  case pReal:
+  case pName:
   case pString:
    return true;
   default:
    return false;
- } 
+ }
 }
 
 /**
@@ -242,11 +261,13 @@ bool isSimple(IProperty* prop) {
 boost::shared_ptr<IProperty> dereference(boost::shared_ptr<IProperty> obj) {
  if (!obj.get()) return obj;  //Empty pointer
  if (obj->getType()!=pRef) return obj;  //Not a reference
- CPdf* pdf=obj->getPdf();
- if (!pdf) return boost::shared_ptr<IProperty>(); //Property does not belong to document -> cannot dereference
- CRef* cref=dynamic_cast<CRef*>(obj.get());
+ boost::shared_ptr<CPdf> pdf=obj->getPdf().lock();
+ // If we are not in valid PDF then CNull is the safe return value
+ // we don't have to check for non NULL and it has reasonable semantics (every
+ // non existing reference points to null object.
+ if (!pdf) return boost::shared_ptr<CNull>(CNullFactory::getInstance());
  IndiRef ref;
- cref->getValue(ref);
+ IProperty::getSmartCObjectPtr<CRef>(obj)->getValue(ref);
  boost::shared_ptr<IProperty> rp=pdf->getIndirectProperty(ref);
  return rp;
 }
@@ -263,17 +284,37 @@ bool isSimple(boost::shared_ptr<IProperty> prop) {
  Save currently active revision in document under different filename
  @param obj Pdf document
  @param name New name
+ @param error String that will receive error message if saving failed. If null, no message will b e received
  @return true if success, false if failure
 */
-bool saveCopy(CPdf *obj,const QString &name) {
+bool saveCopy(boost::shared_ptr<CPdf> obj, const QString &name, QString *error) {
  FILE *f=fopen(name,"wb");
- if (!f) return false; ///failed to open file
+ if (!f) {
+  char *err=strerror(errno);
+  if (err) {
+   (*error)=QObject::tr("Unable to open file: %1").arg(err);
+  } else {
+   (*error)=QObject::tr("Unable to open file: %1").arg(errno);
+  }
+  return false; ///failed to open file
+ }
  try {
   obj->clone(f);
   fclose(f);
   return true;
- } catch (...) {
+ } catch (NotImplementedException &e) {
+  //Close the file
   fclose(f);
+  //Erase the file in case of error to prevent clobbering of disk with empty or broken files
+  unlink(name);
+  (*error)=QObject::tr("Not implemented: %1").arg(e.what());
+  return false;
+ } catch (...) {
+  //Close the file
+  fclose(f);
+  //Erase the file in case of error to prevent clobbering of disk with empty or broken files
+  unlink(name);
+  (*error)=QObject::tr("Unknown error");
   return false;
  }
 }
@@ -350,7 +391,7 @@ boost::shared_ptr<IProperty> getObjProperty(boost::shared_ptr<CArray> obj,const
  return obj->getProperty(index);
 }
 
-/** 
+/**
  Return type identifier of annotation type
  @param at Annotation type
 */
@@ -386,7 +427,7 @@ QString annotType(CAnnotation::AnnotType at) {
  return "?";
 }
 
-/** 
+/**
  Return type identifier of annotation
  @param anot Annotation
 */
@@ -394,7 +435,7 @@ QString annotType(boost::shared_ptr<CAnnotation> anot) {
  return annotType(anot->getType());
 }
 
-/** 
+/**
  Return human readable, localized type identifier of annotation
  @param anot Annotation
 */
@@ -402,4 +443,47 @@ QString annotTypeName(boost::shared_ptr<CAnnotation> anot) {
  return QObject::tr(annotType(anot->getType()),"annotation_type");
 }
 
+/**
+ Get PDF instance - call CPdf::getInstance with appropriate parameters
+ @param parent parent widget of dialog that may spawn
+ @param filename Name of file for CPdf::getInstance
+ @param mode Open mode for CPdf::getInstance
+ @param askPassword If true, password will be asked for if necessary
+*/
+boost::shared_ptr<CPdf> getPdfInstance(QWidget *parent, const QString &filename, CPdf::OpenMode mode, bool askPassword) {
+ boost::shared_ptr<CPdf> pdf=CPdf::getInstance(util::convertFromUnicode(filename,util::NAME).c_str(), mode);
+ if (askPassword && pdf->needsCredentials()) {
+  for(;;) {
+   //Ask for password until we either get the right one or user gets bored with retrying
+   QString pwd=gui::PasswordDialog::ask(parent,QObject::tr("Enter password for %1:").arg(filename));
+
+   //Dialog aborted -> exit
+   if (pwd.isNull()) return pdf;
+
+   //We succedded with passwod -> exit
+   if (setPdfPassword(pdf,pwd)) return pdf;
+  }
+ }
+ return pdf;
+}
+
+/**
+ Try to set PDF password for document.
+ @param pdf CPdf instance
+ @param pass Password to use
+ @return true if the password is correct or false if the password is wrong.
+*/
+bool setPdfPassword(boost::shared_ptr<CPdf> pdf, const QString &pass) {
+ string ownerPasswd, userPasswd;
+ //Password is converted to UTF8. We have no idea in what character set actually is the password
+ //and it is very bad idea to use accented characters in password anyway.
+ ownerPasswd=userPasswd=pass.utf8();
+ try {
+  pdf->setCredentials(ownerPasswd.c_str(),userPasswd.c_str());
+  return true;
+ }catch(PermissionException) {
+ }
+ return false;
+}
+
 } // namespace util
