@@ -1,12 +1,26 @@
-/*                                                                              
- * PDFedit - free program for PDF document manipulation.                        
- * Copyright (C) 2006, 2007  PDFedit team:      Michal Hocko, 
- *                                              Miroslav Jahoda,       
- *                                              Jozef Misutka, 
- *                                              Martin Petricek                                             
+/*
+ * PDFedit - free program for PDF document manipulation.
+ * Copyright (C) 2006-2009  PDFedit team: Michal Hocko,
+ *                                        Jozef Misutka,
+ *                                        Martin Petricek
+ *                   Former team members: Miroslav Jahoda
  *
- * Project is hosted on http://sourceforge.net/projects/pdfedit                                                                      
- */ 
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; version 2 of the License.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program (in doc/LICENSE.GPL); if not, write to the 
+ * Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, 
+ * MA  02111-1307  USA
+ *
+ * Project is hosted on http://sourceforge.net/projects/pdfedit
+ */
 #ifndef __PROPERTYEDITOR_H__
 #define __PROPERTYEDITOR_H__
 
@@ -15,8 +29,8 @@
 #include QDICT
 #include <qmap.h>
 #include <qwidget.h>
-#include <iproperty.h>
-#include <pdfoperators.h>
+#include <kernel/iproperty.h>
+#include <kernel/pdfoperators.h>
 
 class QResizeEvent;
 class Q_ScrollView;
@@ -65,14 +79,14 @@ signals:
   Send property pointer with the signal
   @param prop Pointer to changed property item
  */
- void propertyChanged(IProperty *prop); 
- /** 
+ void propertyChanged(IProperty *prop);
+ /**
   Send informational message when mouse cursor enters/leaves some property
   The message is sent on enter and QString::null on leave.
   @param message Message
  */
  void infoText(const QString &message);
- /** 
+ /**
   Send warning message on some events (only once when the event occurs)
   @param message Message
  */
