@@ -123,7 +123,7 @@ namespace {
 				// characters
 				val.clear();
 				size_t len = obj.getString()->getLength();
-				GString * xpdfString=obj.getString();
+				const GString * xpdfString=obj.getString();
 				for(size_t i=0; i< len; ++i)
 				{
 					char c = xpdfString->getChar(static_cast<int>(i));
@@ -364,7 +364,7 @@ namespace {
 		utilsPrintDbg (debug::DBG_DBG,"\tobjType = " << obj.getTypeName() );
 
 		ostringstream oss;
-		xpdf::XpdfObject o;
+		boost::shared_ptr< ::Object> o(XPdfObjectFactory::getInstance(), xpdf::object_deleter());
 		int i;
 
 		switch (obj.getType()) 
@@ -379,7 +379,7 @@ namespace {
 				string tmp;
 				xpdfObjToString (*o,tmp);
 				oss << tmp;
-				o.reset ();
+				o->free ();
 			}
 			oss << Specification::CARRAY_SUFFIX;
 			break;
@@ -393,7 +393,7 @@ namespace {
 				string tmp;
 				xpdfObjToString (*o,tmp);
 				oss << tmp;
-				o.reset ();
+				o->free ();
 			}
 			oss << Specification::CDICT_SUFFIX;
 			break;
@@ -401,9 +401,9 @@ namespace {
 		case objStream:
 			obj.streamReset ();
 			{
-				Dict* dict = obj.streamGetDict ();
+				const Dict* dict = obj.streamGetDict ();
 				assert (NULL != dict);
-				o->initDict (dict);
+				o->initDict ((Dict*)dict);
 				std::string str;
 				complexXpdfObjToString (*o, str);
 				oss << str;
@@ -445,7 +445,7 @@ namespace {
 			utilsPrintDbg (debug::DBG_DBG, "xpdfArrayReader\tobjType = " << array.getTypeName() );
 			
 			boost::shared_ptr<CPdf> pdf = ip.getPdf ().lock ();
-			XpdfObject obj;
+			boost::shared_ptr< ::Object> obj(XPdfObjectFactory::getInstance(), xpdf::object_deleter());
 
 			int len = array.arrayGetLength ();
 			for (int i = 0; i < len; ++i)
@@ -470,7 +470,7 @@ namespace {
 					// Store it in the storage
 					resultArray.push_back (cobj);
 					// Free resources allocated by the object
-					obj.reset ();
+					obj->free ();
 						
 				}else
 					throw CObjInvalidObject ();
@@ -494,7 +494,7 @@ namespace {
 			utilsPrintDbg (debug::DBG_DBG, "xpdfDictReader\tobjType = " << dict.getTypeName() );
 			
 			boost::shared_ptr<CPdf> pdf = ip.getPdf ().lock ();
-			xpdf::XpdfObject obj;
+			boost::shared_ptr< ::Object> obj(XPdfObjectFactory::getInstance(), xpdf::object_deleter());
 
 			int len = dict.dictGetLength ();
 			for (int i = 0; i < len; ++i)
@@ -602,7 +602,7 @@ getStringFromXpdfStream (std::string& str, ::Object& obj)
 // Creates CObject from xpdf object.
 // 
 IProperty*
-createObjFromXpdfObj (boost::shared_ptr<CPdf> pdf, Object& obj,const IndiRef& ref)
+createObjFromXpdfObj (boost::shared_ptr<CPdf> pdf, const Object& obj,const IndiRef& ref)
 {
 	switch (obj.getType ())
 	{
@@ -644,7 +644,7 @@ createObjFromXpdfObj (boost::shared_ptr<CPdf> pdf, Object& obj,const IndiRef& re
 }
 
 IProperty*
-createObjFromXpdfObj (Object& obj)
+createObjFromXpdfObj (const Object& obj)
 {
 	switch (obj.getType ())
 	{
@@ -712,9 +712,9 @@ template Object* simpleValueToXpdfObj<pRef,const IndiRef&> (const IndiRef& val);
 //
 template <PropertyType Tp,typename T> 
 void
-simpleValueFromXpdfObj (Object& obj, T val)
+simpleValueFromXpdfObj (const Object& obj, T val)
 {
-	typename ProcessorTraitSimple<Object&, T, Tp>::xpdfReadProcessor rp;
+	typename ProcessorTraitSimple<const Object&, T, Tp>::xpdfReadProcessor rp;
 	rp (obj,val);
 }
 
@@ -723,7 +723,7 @@ simpleValueFromXpdfObj (Object& obj, T val)
 //
 template <> 
 inline void
-simpleValueFromXpdfObj<pNull,NullType&> (Object&, NullType&) 
+simpleValueFromXpdfObj<pNull,NullType&> (const Object&, NullType&) 
 {
 	/*assert (!"operation not permitted...");*//*THIS IS FORBIDDEN IN THE CALLER*/
 }
@@ -734,20 +734,20 @@ simpleValueFromXpdfObj<pNull,NullType&> (Object&, NullType&)
 //
 template <PropertyType Tp,typename T> 
 inline void
-complexValueFromXpdfObj (IProperty& ip, Object& obj, T val)
+complexValueFromXpdfObj (IProperty& ip, const Object& obj, T val)
 {
-	typename ProcessorTraitComplex<Object&, T, Tp>::xpdfReadProcessor rp;
+	typename ProcessorTraitComplex<const Object&, T, Tp>::xpdfReadProcessor rp;
 	rp (ip, obj, val);
 }
 
 template void complexValueFromXpdfObj<pArray, CArray::Value&> 
 		(IProperty& ip, 
-		 Object& obj, 
+		 const Object& obj, 
 		 CArray::Value& val);
 
 template void complexValueFromXpdfObj<pDict, CDict::Value&>
 		(IProperty& ip, 
-		 Object& obj, 
+		 const Object& obj, 
 		 CDict::Value& val);
 
 
@@ -763,15 +763,16 @@ dictFromXpdfObj (CDict& resultDict, ::Object& dict)
 	assert (0 <= dict.dictGetLength ());
 	utilsPrintDbg (debug::DBG_DBG, "" );
 			
-	xpdf::XpdfObject obj;
+ 	boost::shared_ptr< ::Object> obj(XPdfObjectFactory::getInstance(), xpdf::object_deleter());
 
 	int len = dict.dictGetLength ();
 	for (int i = 0; i < len; ++i)
 	{
-		// Make string from key
+		// get rid of previous value and fetch the current one
+		obj->free();
 		string key = dict.dictGetKey (i);
-		// Make IProperty from value
 		dict.dictGetValNF (i,obj.get());
+		// Make IProperty from value
 		scoped_ptr<IProperty> cobj (createObjFromXpdfObj (*obj));
 		if (cobj)
 		{
@@ -922,7 +923,7 @@ unsigned char* bufferFromStream(Stream& str, size_t dictLength, size_t& size)
 	return buffer;
 }
 
-unsigned char* convertStreamToDecodedData(Object& obj, size_t& size)
+unsigned char* convertStreamToDecodedData(const Object& obj, size_t& size)
 {
 	Object lenObj;
 	obj.streamGetDict()->lookup("Length", &lenObj);
@@ -942,7 +943,7 @@ unsigned char* convertStreamToDecodedData(Object& obj, size_t& size)
 	const char * fieldsToRemove[] = {"Filter", "DecodeParams", "F", "FFilter", "FDecodeParams", "DL", NULL};
 	for(int i=0; fieldsToRemove[i]; ++i)
 	{
-		Object * entry = obj.streamGetDict()->del(fieldsToRemove[i]);
+		Object * entry = obj.getStream()->getBaseStream()->dictDel(fieldsToRemove[i]);
 		if(entry)
 		{
 			utilsPrintDbg(debug::DBG_DBG, "Removing "<< fieldsToRemove[i] <<" entry from the stream");
@@ -953,7 +954,7 @@ unsigned char* convertStreamToDecodedData(Object& obj, size_t& size)
 	return buffer;
 }
 
-size_t streamToCharBuffer (Object & streamObject, Ref* ref, CharBuffer & outputBuf, 
+size_t streamToCharBuffer (const Object & streamObject, Ref* ref, CharBuffer & outputBuf, 
 		stream_data_extractor extractor)
 {
 	utilsPrintDbg(debug::DBG_DBG, "");
@@ -964,20 +965,18 @@ size_t streamToCharBuffer (Object & streamObject, Ref* ref, CharBuffer & outputB
 	}
 	
 	// gets buffer len from stream dictionary Length field
-	Object lenghtObj;
-	Dict *streamDict = streamObject.streamGetDict();
-	streamDict->lookup("Length", &lenghtObj);
-	if(!lenghtObj.isInt())
+	boost::shared_ptr< ::Object> lenghtObj(XPdfObjectFactory::getInstance(), xpdf::object_deleter());
+ 	streamObject.streamGetDict()->lookup("Length", lenghtObj.get());
+	if(!lenghtObj->isInt())
 	{
-		utilsPrintDbg(debug::DBG_ERR, "Stream dictionary Length field is not int. type="<<lenghtObj.getType());
-		lenghtObj.free();
+		utilsPrintDbg(debug::DBG_ERR, "Stream dictionary Length field is not int. type="<<lenghtObj->getType());
 		return 0;
 	}
 	// we don't need to call free for lenghtObj because it is 
 	// int which doesn't allocate any memory for internal data
-	if(0>lenghtObj.getInt())
+	if(0>lenghtObj->getInt())
 	{
-		utilsPrintDbg(debug::DBG_ERR, "Stream dictionary Length field doesn't have correct value. value="<<lenghtObj.getInt());
+		utilsPrintDbg(debug::DBG_ERR, "Stream dictionary Length field doesn't have correct value. value="<<lenghtObj->getInt());
 		return 0;
 	}
 	
@@ -1008,12 +1007,12 @@ size_t streamToCharBuffer (Object & streamObject, Ref* ref, CharBuffer & outputB
 	// Update dict stream with the new Length value (if necessary)
 	// TODO indirect value would be much better, but we don't have
 	// access to the XrefWriter here
-	if (lenghtObj.getInt() != realBufferLen)
+	if (lenghtObj->getInt() != realBufferLen)
 	{
-		lenghtObj.initInt(realBufferLen);
+		lenghtObj->initInt(realBufferLen);
 		// don't need to give copyString(Length) because we are sure, that
 		// this entry already exists
-		Object* oldLen = streamDict->update("Length", &lenghtObj);
+ 		Object* oldLen = streamObject.getStream()->getBaseStream()->dictUpdate("Length", lenghtObj.get());
 		if(oldLen)
 			freeXpdfObject(oldLen);
 	}
@@ -1022,11 +1021,10 @@ size_t streamToCharBuffer (Object & streamObject, Ref* ref, CharBuffer & outputB
 	// for Dict -> String conversion
 	// initDict increases streamDict's reference thus we need to
 	// decrease it back by free
-	Object streamDictObj;
-	streamDictObj.initDict(streamDict);
+	shared_ptr< ::Object> streamDictObj(XPdfObjectFactory::getInstance(), xpdf::object_deleter());
+	streamDictObj->initDict((Dict *)streamObject.streamGetDict());
 	std::string dict;
-	xpdfObjToString(streamDictObj, dict);
-	streamDictObj.free();
+	xpdfObjToString(*streamDictObj, dict);
 
 	// gets total length and allocates CharBuffer for output
 	size_t len = header.length() + 
