@@ -592,7 +592,24 @@ public:
 		_contents->replaceText (what, with);
 	}
 
+	/**
+	 * Adds text to specified position.
+	 */
+	void addText (const std::string& what, 
+				  const libs::Point& where, 
+				  const std::string& font_id)
+	{
+			_check_validity();
+		_contents->addText (what, where, font_id);
+	}
 
+	void addInlineImage (const CStream::Buffer& what,
+  						 const libs::Point& dim,
+						 const libs::Point& where)
+	{
+			_check_validity();
+		_contents->addInlineImage (what, dim, where);
+	}
 	 //
 	 // Helper functions
 	 //
