@@ -1,9 +1,9 @@
 /*
  * PDFedit - free program for PDF document manipulation.
- * Copyright (C) 2006, 2007, 2008  PDFedit team: Michal Hocko,
- *                                              Miroslav Jahoda,
- *                                              Jozef Misutka,
- *                                              Martin Petricek
+ * Copyright (C) 2006-2009  PDFedit team: Michal Hocko,
+ *                                        Jozef Misutka,
+ *                                        Martin Petricek
+ *                   Former team members: Miroslav Jahoda
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -39,13 +39,13 @@
 #include <xpdf/Page.h>
 #include <xpdf/TextOutputDev.h>
 #include <xpdf/SplashOutputDev.h>
+#include <xpdf/BuiltinFontTables.h>
 // Note that GlobalParams::initGlobalParams has to be called before
 // we can use globalParams.
 // If we want to use fonts correctly, globalParams->setupBaseFonts(NULL)
 // has to be called
 #include <xpdf/GlobalParams.h>
 #include <xpdf/Catalog.h>
-#include <xpdf/PDFDoc.h>
 
 #include <assert.h>
 
@@ -89,50 +89,6 @@ struct object_deleter
 	void operator() (::Object* o)
 		{ assert (o); o->free(); ::gfree(o); }
 };
-					
-	
-/** 
- * Wrapper around a class which uses free method.
- *
- * This class uses a special free method to deallocate objects. 
- * In xpdf Object class the free method is necessary because Object implements reference 
- * counting.
- */
-template<typename T>
-class MassiveIdiocyWrapper // : noncopyable 
-{
-private:
-	T obj;
-	
-	/** Disallow copy ctor. */
-	MassiveIdiocyWrapper (const MassiveIdiocyWrapper&);
-	/** Disallow copy ctor. */
-	const MassiveIdiocyWrapper& operator= (const MassiveIdiocyWrapper&);
-	
-public:	
-	typedef T element_type;
-
-	/** Constructor. */
-	MassiveIdiocyWrapper () {}
-
-	/** Explicit delete.	*/
-	void reset () { obj.free (); }
-	
-	/** Dereference. */
-	T& operator*() /*const*/ { return obj; }
-	/** Dereference. */
-	T* operator->() /*const*/ { return &obj; }
-
-	/** Get raw pointer. */
-	T* get () /*const*/ { return &obj; }
-	
-	/** Destructor. */
-	~MassiveIdiocyWrapper () { obj.free (); }
-};
-
-/** Xpdf object wrapper. */
-typedef MassiveIdiocyWrapper<Object> XpdfObject;
-
 
 /**
  * Free an object. We assume that all child objects (if any)
