@@ -1,139 +1,27 @@
-/*                                                                              
- * PDFedit - free program for PDF document manipulation.                        
- * Copyright (C) 2006, 2007  PDFedit team:      Michal Hocko, 
- *                                              Miroslav Jahoda,       
- *                                              Jozef Misutka, 
- *                                              Martin Petricek                                             
- *
- * Project is hosted on http://sourceforge.net/projects/pdfedit                                                                      
- */ 
-// vim:tabstop=4:shiftwidth=4:noexpandtab:textwidth=80
 /*
- * $RCSfile: observer.h,v $
+ * PDFedit - free program for PDF document manipulation.
+ * Copyright (C) 2006-2009  PDFedit team: Michal Hocko,
+ *                                        Jozef Misutka,
+ *                                        Martin Petricek
+ *                   Former team members: Miroslav Jahoda
  *
- * $Log: observer.h,v $
- * Revision 1.27  2007/02/04 20:17:03  mstsxfx
- * Common Licence comment for all cc and h files available in doc/licence_header
- * file and its content to all cc and h files in src/{gui,kernel,utils}
- * directories.
- * Xpdf code, QSA and QOutputDevice code are not touched
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; version 2 of the License.
  *
- * Revision 1.26  2006/09/11 13:50:39  misuj1am
- *
- * -- one hack removed
- * 	-- added to assure " a bit " more stability
- *
- * Revision 1.25  2006/09/07 10:31:30  misuj1am
- *
- * -- hack
- *
- * Revision 1.24  2006/08/26 10:19:33  hockm0bm
- * FIXME removed
- *
- * Revision 1.23  2006/06/17 18:34:51  hockm0bm
- * Refactoring changes
- *
- * * IObserverHandler
- *         -renamed to ObserverHandler - it is not interface
- *         - BasicObserverContext, CDictComplexObserverContext,
- *           CArrayComplexObserverContext removed - it doesn't have to know
- *           anything about existing context types
- * * CObjectSimple, CDict, CArray, CStream, CPage, CAnnotation, CContentStream
- *         - each provides typedef with produced change context
- *
- * Revision 1.22  2006/06/17 17:40:57  hockm0bm
- * * PriorityComparator
- *         - functor behaves like less
- * * PriorityList reimplemented
- *         - doesn't inherit from priority_queue - implements sorting directly
- *         - uses container with given type and sort function when element is
- *           inserted and removed
- *
- * Revision 1.21  2006/06/17 16:48:38  hockm0bm
- * ObserverHandler::registerObserver bug fix
- *         - obsever is pushed if find returns == end()
- *
- * Revision 1.20  2006/06/17 15:40:07  misuj1am
- *
- * -- minor changes
- *
- * Revision 1.19  2006/06/17 15:06:20  hockm0bm
- * quick fix
- *         - <std_queue.h> include replaced by <queue>
- *
- * Revision 1.18  2006/06/17 13:15:29  hockm0bm
- * * PriorityList added
- * * PriorityComparator added
- * * IObserverHandler
- *         - supports priorities - uses PriorityList storage
- *         - registerObserver wih already registered obsever is ignored
- *
- * NEEDS testing
- *
- * Revision 1.17  2006/06/15 15:56:00  jahom0bm
- * Fixed include
- *
- * Revision 1.16  2006/06/13 20:44:13  hockm0bm
- * * ChangeContextType enum removed from class IChangeContext to observer namespace
- * * pdfwriter.cc synced with ChangeContextType change
- *
- * Revision 1.15  2006/06/12 18:28:14  hockm0bm
- * ComplexChangeContext class added
- *
- * Revision 1.14  2006/05/30 21:04:12  hockm0bm
- * doc update
- *
- * Revision 1.13  2006/05/30 10:51:08  misuj1am
- *
- * -- improved
- *
- * Revision 1.12  2006/05/16 17:43:58  hockm0bm
- * * ScopedChangeContext added
- *         - new change context
- *
- * Revision 1.11  2006/05/14 13:51:40  hockm0bm
- * quick fix
- *         - virtual destructor for IObserverHandler
- *
- * Revision 1.10  2006/05/14 13:29:00  hockm0bm
- * IObserverHandler has virtual methods
- *
- * Revision 1.9  2006/05/14 12:51:46  misuj1am
- *
- * -- implementation moved from iproperty.cc here
- *
- * Revision 1.8  2006/04/18 17:25:29  hockm0bm
- * IObserverHandler returned back
- *
- * Revision 1.7  2006/04/17 17:08:10  hockm0bm
- * throw() added to all methods which can't throw
- *
- * Revision 1.6  2006/04/16 23:04:53  misuj1am
- *
- *
- * -- slightly changed observer interface
- *
- * Revision 1.5  2006/04/12 17:58:28  hockm0bm
- * BasicChangeContext changed to BasicChangeContextType
- *
- * Revision 1.4  2006/04/09 21:32:03  misuj1am
- *
- *
- * -- changed a bit
- * 	-- virtual destructor
- * 	-- pointer to context changed to shared_ptr
- *
- * Revision 1.3  2006/04/02 08:09:59  hockm0bm
- * new observer design
- * * IObserver - interface for observer implementation (template class)
- * * IObserverHandler - interface for value keepers which wants to be
- *         registration target of observers (template class)
- * * IChangeContext - interface for change context for notifier (template class)
- *         - BasicCahngeContext - implementation of basic context with original
- *           value of changed one
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  *
+ * You should have received a copy of the GNU General Public License
+ * along with this program (in doc/LICENSE.GPL); if not, write to the 
+ * Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, 
+ * MA  02111-1307  USA
  *
+ * Project is hosted on http://sourceforge.net/projects/pdfedit
  */
+// vim:tabstop=4:shiftwidth=4:noexpandtab:textwidth=80
 
 #ifndef _OBSERVER_H
 #define _OBSERVER_H
@@ -143,6 +31,9 @@
 #include <boost/shared_ptr.hpp>
 #include <iostream>
 #include <algorithm>
+#include "os/compiler.h"
+
+#include "utils/debug.h"
 
 //=============================================================================
 namespace observer
@@ -202,7 +93,7 @@ public:
 	/** Virtual destructor.
 	 *
 	 */
-	virtual ~IChangeContext(){};
+	virtual ~IChangeContext(){}
 };
 
 /** Basic change context template class.
@@ -221,12 +112,12 @@ public:
 	/** Constructor with original value.
 	 * @param origVal Original value used for originalValue initialization.
 	 */
-	BasicChangeContext(boost::shared_ptr<T> origVal)throw() :originalValue(origVal){};
+	BasicChangeContext(boost::shared_ptr<T> origVal)throw() :originalValue(origVal){}
 
 	/** Destructor.
 	 * Just to mark all destructors in subtypes as virtual.
 	 */
-	virtual ~BasicChangeContext()throw() {};
+	virtual ~BasicChangeContext()throw() {}
 
 	/** Returns type of context.
 	 *
@@ -265,7 +156,7 @@ public:
 	/** Initialization constructor.
 	 * @param origVal Original value.
 	 * @param id Identificator of changed value.
-	 * 
+	 *
 	 * Initializes originalValue (uses BasicChangeContext constructor with
 	 * origVal parameter) and valueId from given id.
 	 */
@@ -316,7 +207,7 @@ public:
 	 *
 	 * Initializes scope field.
 	 */
-	ScopedChangeContext(boost::shared_ptr<S> s):scope(s){};
+	ScopedChangeContext(boost::shared_ptr<S> s):scope(s){}
 
 	/** Returns scope.
 	 * @return Scope value wrapped by shared_ptr smart pointer.
@@ -346,7 +237,7 @@ public:
  * This should be used in following way:
  * <ul>
  * <li>value keeper which wants to enable observers has to implement
- * IObserverHandler interface which enables to register and unregister 
+ * ObserverHandler interface which enables to register and unregister 
  * observers. It guaranties it calls notify on each registered observer after
  * change was registered.
  * <li>implementator of class is responsible for notify method implementation
@@ -365,21 +256,32 @@ public:
  * Each observer implementation has its priority which is used be value keeper
  * to determine order in which to notify obsevers, if there is more then one.
  * <br>
+ * Observer can be in active/inactive state depending on the active flag value.
+ * See setActive, isActive methods.
+ * <br>
  * Exception NOTE:
  * No method throws an exception.
  */
 template<typename T> class IObserver
 {
+	/** Active flag.
+	 * Observer is ignored by observer handler if it is false.
+	 */
+	bool active;
 public:
 	/** Type for priority.
 	 */
 	typedef int priority_t;
+
+	/** Default constructor.
+	 */
+	IObserver():active(true) {}
 	
 	/** Notify method.
 	 * @param newValue New value of changed value or its part.
 	 * @param context Value change context.
 	 * 
-	 * Each time value keeper, which implements IObserverHandler, changes 
+	 * Each time value keeper, which implements ObserverHandler, changes 
 	 * value (or its part), all registered observers are notified about that
 	 * by this method calling.
 	 * <br>
@@ -408,14 +310,31 @@ public:
 	 */
 	virtual priority_t getPriority()const throw() =0;
 
+	/** Sets active flag value.
+	 * @param active Flag value to be set.
+	 * @return previous value of the flag.
+	 */
+	bool setActive(bool active)
+	{
+		bool oldValue = this->active;
+		this->active = active;
+		return oldValue;
+	}
+
+	/** Returns current value of the active flag.
+	 * @return true if observer can be notified, false otherwise.
+	 */
+	bool isActive()const
+	{
+		return active;
+	}
+
 	/**
 	 * Virtual destructor.
 	 */
-	virtual ~IObserver ()throw() {};
+	virtual ~IObserver ()throw() {}
 };
 
-namespace {
-
 /** Priority comparator functor.
  *
  * T template parameter stands for elements which priority should be compared.
@@ -521,12 +440,95 @@ public:
 			}
 		}
 	}
+
+	/** Returns number of registered elements.
+	 * @return number of elements.
+	 */
+	size_t size()const
+	{
+		return c.size();
+	}
 };
 
-} // annonymous namespace for priority list and related
+#ifdef OBSERVER_DEBUG
+/** Helper macro for debug information printing.
+ * Note that this will be empty if OBSERVER_DEBUG is not defined.
+ */
+#define PRINT_DEBUG_INFO(obj, observer, prefix)		\
+	do {						\
+		std::cerr << prefix <<"("<<(obj) <<","<<(observer)<<") from ";\
+		std::cerr <<__FILE__ <<":"<< __FUNCTION__ <<":"<< __LINE__ << std::endl;\
+	} while (0)
+#else
+#define PRINT_DEBUG_INFO(obj, observer, prefix) do {} while(0)
+#endif
+
+/** Wrapper for observer registration.
+ * @param obj Observer handler (ObserverHandler wrapped by shared_ptr).
+ * @param observer Observer to be registered (IObserver wrapped by shared_ptr).
+ *
+ * Note that this way of observer registration is preffered because
+ * of possible debug information.
+ * <br>
+ * Don't use expression parameters with side effects (e.g. ++i etc.), 
+ * because they may be executed more than once (if debuging is used).
+ */
+#define REGISTER_SHAREDPTR_OBSERVER(obj, observer)	\
+	do {					\
+		PRINT_DEBUG_INFO((obj).get(), (observer).get(), "registerObserver");\
+		obj->registerObserver(observer);\
+	}while(0)
+
+/** Wrapper for observer unregistration.
+ * @param obj Observer handler (ObserverHandler wrapped by shared_ptr).
+ * @param observer Observer to be registered (IObserver wrapped by shared_ptr).
+ *
+ * Note that this way of observer unregistration is preffered because
+ * of possible debug information.
+ * <br>
+ * Don't use expression parameters with side effects (e.g. ++i etc.), 
+ * because they may be executed more than once (if debuging is used).
+ */
+#define UNREGISTER_SHAREDPTR_OBSERVER(obj, observer)	\
+	do {					\
+		PRINT_DEBUG_INFO((obj).get(), (observer).get(), "unregisterObserver");\
+		obj->unregisterObserver(observer);\
+	}while(0)
+
+/** Wrapper for observer registration.
+ * @param obj Observer handler (simple pointer to ObserverHandler).
+ * @param observer Observer to be registered (simple pointer to IObserver).
+ *
+ * Note that this way of observer registration is preffered because
+ * of possible debug information.
+ * <br>
+ * Don't use expression parameters with side effects (e.g. ++i etc.), 
+ * because they may be executed more than once (if debuging is used).
+ */
+#define REGISTER_PTR_OBSERVER(obj, observer)	\
+	do {					\
+		PRINT_DEBUG_INFO((obj), (observer), "registerObserver");\
+		obj->registerObserver(observer);\
+	}while(0)
+
+/** Wrapper for observer unregistration.
+ * @param obj Observer handler (simple pointer to ObserverHandler).
+ * @param observer Observer to be unregistered (simple pointer to IObserver).
+ *
+ * Note that this way of observer unregistration is preffered because
+ * of possible debug information.
+ * <br>
+ * Don't use expression parameters with side effects (e.g. ++i etc.), 
+ * because they may be executed more than once (if debuging is used).
+ */
+#define UNREGISTER_PTR_OBSERVER(obj, observer)	\
+	do {					\
+		PRINT_DEBUG_INFO((obj), (observer), "unregisterObserver");\
+		obj->unregisterObserver(observer);\
+	}while(0)
 
 /** Base class for all notifiers.
- *
+ a*
  * Each class which want to support observers should inherit from this class. It
  * provides basic implementation for registering, unregistering and notification
  * of observers.
@@ -564,11 +566,29 @@ protected:
 	 * means smaller priority value.
 	 */
 	ObserverList observers;
-	
+
+	/** Prints all registered observers.
+	 * Each observer is printed as pointer address. 
+	 * Method is empty if OBSERVER_DEBUG is not defined.
+	 */
+	void dumpObservers()const
+	{
+#ifdef OBSERVER_DEBUG
+		size_t size = observers.size();
+		std::cerr << " observer list (size="
+				<<size<<"): ";
+		typename ObserverList::const_iterator it = observers.begin();
+		for(;it!=observers.end(); ++it)
+		{
+			Observer observer = *it;
+			std::cerr << observer.get() << " ";
+		}
+#endif
+	}
 public:
 	/** Empty destructor.
 	 */
-	virtual ~ObserverHandler(){}
+	virtual ~ObserverHandler() {}
 	
 	/** Registers new observer.
 	 * @param observer Observer to register (if NULL, nothing is registered).
@@ -614,11 +634,12 @@ public:
 	}
 
 	/**
-	 * Notify all observers about a change.
+	 * Notify all active observers about a change.
 	 *
 	 * Observers are notified in according their priorities. Higher priority
 	 * (smaller priority value) sooner it is called. Observers with same
-	 * priorities are called in unspecified order. 
+	 * priorities are called in unspecified order. All inactive observers
+	 * are ignored.
 	 *
 	 * @param newValue Object with new value.
 	 * @param context Context in which the change has been made.
@@ -628,12 +649,32 @@ public:
 		// obsrvers list is ordered by priorities, so iteration works correctly
 		typename ObserverList::const_iterator it = observers.begin ();
 		for (; it != observers.end(); ++it)
-			(*it)->notify (newValue, context);
+		{
+			Observer o = (*it);
+			if(o->isActive())
+				o->notify (newValue, context);
+		}
 	}
 	
 };
 
 
+/**
+ * Checks whether the observer list is empty.
+ */
+template<typename T>
+inline static void 
+check_observerlist (UNUSED_PARAM const T& list) 
+{
+#ifdef OBSERVER_DEBUG
+	if (list.size()) 
+	{
+		kernelPrintDbg (debug::DBG_CRIT, "unregistered observer(s): " << list.size());
+	}
+#endif
+}
+
+
 } // namespace observer
 
 
